-- File: createTablesPg.sql
-- Andrew Jarcho
-- modified 4/19/07 6:45p
-- create tables for MSTS project  MIGRATED TO POSTGRESQL
-- create sequences
-- create initial administrator account
 

-- create account table
-- there will be one Administrator account
-- and accounts for each Mediator and Client
DROP TABLE ms_account CASCADE;

CREATE TABLE ms_account
(logname          VARCHAR(20),
 lastName         VARCHAR(30) NOT NULL,
 firstName        VARCHAR(30) NOT NULL,
 middleInitial    CHAR(1),
 homePhone        VARCHAR(20),
 workPhone        VARCHAR(20),
 cellPhone        VARCHAR(20),
 email            VARCHAR(100) NOT NULL,
 password         VARCHAR(40) NOT NULL,
 PRIMARY KEY (logname));
 

-- create logInOut table
-- tracks time of logins, logouts
DROP TABLE ms_logInOut CASCADE;

CREATE TABLE ms_logInOut
(logname          VARCHAR(20),
 logDate          TIMESTAMP WITH TIME ZONE,
 isLogin          CHAR(1) NOT NULL CHECK (isLogin IN ('y', 'n')),
 PRIMARY KEY (logname, logDate),
 FOREIGN KEY (logname) REFERENCES ms_account);              


-- create case table
DROP TABLE ms_case CASCADE;

CREATE TABLE ms_case
(caseID           INTEGER,
 caseTitle        VARCHAR(40) NOT NULL UNIQUE,
 PRIMARY KEY (caseID));


-- create accountCaseRole table
DROP TABLE ms_accountCaseRole CASCADE;

CREATE TABLE ms_accountCaseRole
(logname          VARCHAR(20),
 caseID           INTEGER,
 role             VARCHAR(20) NOT NULL CHECK (role IN ('Mediator', 'Client', 'Admin')),
 PRIMARY KEY (logname, caseID),
 FOREIGN KEY (logname) REFERENCES ms_account,
 FOREIGN KEY (caseID) REFERENCES ms_case);


-- create caseState table
DROP TABLE ms_caseState CASCADE;

CREATE TABLE ms_caseState
(caseID           INTEGER,
 caseStatus       VARCHAR(20),
 statusDate       TIMESTAMP WITH TIME ZONE NOT NULL,
 PRIMARY KEY (caseID, caseStatus),
 FOREIGN KEY (caseID) REFERENCES ms_case);


-- create document table
DROP TABLE ms_document CASCADE;

CREATE TABLE ms_document
(docID            INTEGER,
 type             VARCHAR(20) NOT NULL,
 caseID           INTEGER,
 docOut           CHAR(1) NOT NULL CHECK (docOut IN ('y', 'n')),
 PRIMARY KEY (docID),
 FOREIGN KEY (caseID) REFERENCES ms_case);


-- create document version table
DROP TABLE ms_docVersion CASCADE;

CREATE TABLE ms_docVersion
(docID            INTEGER,
 version          INTEGER,
 dateCreated      TIMESTAMP WITH TIME ZONE NOT NULL,
 title            VARCHAR(40),
 body             VARCHAR,
 PRIMARY KEY (docID, version),
 FOREIGN KEY (docID) REFERENCES ms_document);


-- create document access table
DROP TABLE ms_docAccess CASCADE;

CREATE TABLE ms_docAccess
(docID            INTEGER,
 logname          VARCHAR(20),
 PRIMARY KEY (docID, logname),
 FOREIGN KEY (docID) REFERENCES ms_document,
 FOREIGN KEY (logname) REFERENCES ms_account);


-- create document signature table
DROP TABLE ms_docSignature CASCADE;

CREATE TABLE ms_docSignature
(docID            INTEGER,
 version          INTEGER,
 logname          VARCHAR(20),
 sigDate          TIMESTAMP WITH TIME ZONE NOT NULL,
 sigPlace         VARCHAR(40) NOT NULL,
 PRIMARY KEY (docID, version, logname),
 FOREIGN KEY (docID) REFERENCES ms_document,
 FOREIGN KEY (docID, version) REFERENCES ms_docVersion,
 FOREIGN KEY (docID, logname) REFERENCES ms_docAccess,
 FOREIGN KEY (logname) REFERENCES ms_account);


-- create meeting table
-- records a scheduled meeting
-- date/time and status
DROP TABLE ms_meeting CASCADE;

CREATE TABLE ms_meeting
(meetingID        INTEGER,
 meetingStart        TIMESTAMP WITH TIME ZONE NOT NULL,
 meetingEnd          TIMESTAMP WITH TIME ZONE,
 meetingStatus       VARCHAR(20) NOT NULL CHECK (meetingStatus IN ('open', 'held', 'cancelled')),
 PRIMARY KEY (meetingID));


-- create attendance table
-- records who is scheduled to attend a meeting
-- and whether they were actually present
DROP TABLE ms_attendance CASCADE;

CREATE TABLE ms_attendance
(meetingID        INTEGER,
 logname          VARCHAR(20),
 present          CHAR(1) CHECK (present IN ('y', 'n')),
 PRIMARY KEY (meetingID, logname),
 FOREIGN KEY (meetingID) REFERENCES ms_meeting);


-- create sequence for ms_case::caseID
DROP SEQUENCE ms_caseIDSeq;

CREATE SEQUENCE ms_caseIDSeq START WITH 1000;


-- create sequence for ms_document::docID
DROP SEQUENCE ms_docIDSeq;

CREATE SEQUENCE ms_docIDSeq START WITH 1;


-- create the default account
INSERT INTO ms_account (logname, password, lastName, firstName, email)
values('Admin01', 'Admin01', 'Admin01', 'Admin01', 'Admin01@Admin01');
